var argv = process.argv.slice(1);
if(argv.length < 2) {
  console.log('Usage: server.js spec_file\n');
  process.exit();
}

const fs = require('fs')
const spec_file = argv[1];

try {
  if (fs.existsSync(spec_file)) {
    console.log('Loading spec file ' + spec_file);
  }
} catch(err) {
  console.error('File ' + spec_file + ' not found');
  process.exit();
}

const express = require('express');
const bodyParser = require('body-parser');
const http = require('http');
const app = express();

const OpenApiValidator = require('express-openapi-validator').OpenApiValidator;

app.use(bodyParser.json());

new OpenApiValidator({
  apiSpec: spec_file,
  validateResponses: true
})
  .install(app)
  .then(() => {

    app.use((err, req, res, next) => {
      res.status(err.status || 500).json({
        message: err.message,
        errors: err.errors,
      });
    });

    http.createServer(app).listen(3000);
  });

